@@ -1,5 +1,6 @@
 from enum import Enum
-from typing import Union, Literal, Any
+from typing_extensions import Literal
+from typing import Union, Any
 
 from pydantic import BaseModel, Field
 
@@ -50,7 +51,7 @@ class StripeBaseEvent(BaseModel):
     api_version: str
     request: StripeEventRequest
     data: Any  # overwrite this attribute when inheriting
-    type: Literal[Any]  # overwrite this attribute when inheriting
+    type: Literal[str]  # overwrite this attribute when inheriting
 
 
 class StripeInvoiceEvent(StripeBaseEvent):
